==> zio-aws-apigatewayv2_3-5.17.102.7-sources.jar: zio/aws/apigatewayv2/model/DeleteApiRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteApiRequest(apiId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.DeleteApiRequest = {
    import DeleteApiRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.DeleteApiRequest
      .builder()
      .apiId(__string.unwrap(apiId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.DeleteApiRequest.ReadOnly =
    zio.aws.apigatewayv2.model.DeleteApiRequest.wrap(buildAwsValue())
}
object DeleteApiRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.DeleteApiRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.DeleteApiRequest =
      zio.aws.apigatewayv2.model.DeleteApiRequest(apiId)
    def apiId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteApiRequest
  ) extends zio.aws.apigatewayv2.model.DeleteApiRequest.ReadOnly {
    override val apiId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.apiId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteApiRequest
  ): zio.aws.apigatewayv2.model.DeleteApiRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-apigatewayv2_3-6.20.69.1-sources.jar: zio/aws/apigatewayv2/model/DeleteApiRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteApiRequest(apiId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.DeleteApiRequest = {
    import DeleteApiRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.DeleteApiRequest
      .builder()
      .apiId(apiId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.DeleteApiRequest.ReadOnly =
    zio.aws.apigatewayv2.model.DeleteApiRequest.wrap(buildAwsValue())
}
object DeleteApiRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.DeleteApiRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.DeleteApiRequest =
      zio.aws.apigatewayv2.model.DeleteApiRequest(apiId)
    def apiId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteApiRequest
  ) extends zio.aws.apigatewayv2.model.DeleteApiRequest.ReadOnly {
    override val apiId: __string = impl.apiId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteApiRequest
  ): zio.aws.apigatewayv2.model.DeleteApiRequest.ReadOnly = new Wrapper(impl)
}
